@@ -177,11 +177,11 @@ def ui_string(message, *args):
 
     Typical use (replace debug with any other method):
 
-    >>> import mercurial.ui; ui = mercurial.ui.ui()
-    >>> ui.debug(ui_string("Simple text"))
-    >>> ui.debug(ui_string(b"Simple binary"))
-    >>> ui.debug(ui_string("This is %s and %s and %s", b'bin', u'txt', None))
-    >>> ui.debug(ui_string(b"This is %s and %s and %s", b'bin', u'txt', None))
+    >>> import mercurial.ui; uio = mercurial.ui.ui()
+    >>> uio.debug(ui_string("Simple text"))
+    >>> uio.debug(ui_string(b"Simple binary"))
+    >>> uio.debug(ui_string("This is %s and %s and %s", b'bin', u'txt', None))
+    >>> uio.debug(ui_string(b"This is %s and %s and %s", b'bin', u'txt', None))
 
     This works because we reasonably create binary strings, as ui expects:
 
